package io.platform.sys.web.controller.rest;

import cn.hutool.core.io.FileUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.*;
import io.platform.base.common.validator.ValidatorUtils;

import io.platform.sys.dto.SysFileDto;
import io.platform.sys.web.remote.SysFileServiceRemote;

import org.apache.shiro.authz.annotation.RequiresPermissions;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/sysFile")
public class SysFileRestController extends AbstractController {

    @Autowired
	private SysFileServiceRemote sysFileServiceRemote;

	@Resource
	private FtpUtils ftpUtils;
	
	/**
	 * 所有列表
	 */
	@RequestMapping("/list")
	@RequiresPermissions("sys:sysFile:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", sysFileServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@RequestMapping("/page")
	@RequiresPermissions("sys:sysFile:page")
	public R page(Page page, SysFileDto sysFileDto){
		return R.ok().put("page", sysFileServiceRemote.getPage(page,sysFileDto));
	}
	/**
	 * 信息
	 */
	@RequestMapping("/info/{id}")
	@RequiresPermissions("sys:sysFile:info")
	public R info(@PathVariable("id") Long id){
		SysFileDto sysFileDto = sysFileServiceRemote.getOne(id);
		return R.ok().put("sysFileDto", sysFileDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@RequestMapping("/save")
	@RequiresPermissions("sys:sysFile:edit")
	public R save(@RequestBody SysFileDto sysFileDto){
        ValidatorUtils.validateEntity(sysFileDto);
        ExecuteResult<String> result= sysFileServiceRemote.save(sysFileDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@RequestMapping("/update")
	@RequiresPermissions("sys:sysFile:edit")
	public R update(@RequestBody SysFileDto sysFileDto){
        ValidatorUtils.validateEntity(sysFileDto);
        ExecuteResult<String> result= sysFileServiceRemote.update(sysFileDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@RequestMapping("/delete")
	@RequiresPermissions("sys:sysFile:edit")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= sysFileServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

	/**
	 * 图片上传
	 * 带打水印
	 */
	@SysLog("图片上传")
	@RequestMapping("/uploadImg")
	//@RequiresPermissions("sys:sysFile:uploadImg")
	public ReturnJson uploadImg(@RequestParam("file") MultipartFile file) {
		//图片上传
		String path = "/file/";
		ReturnJson json = new ReturnJson();
		Map<String,Object> map = new HashMap<>();
		String accessFilePath = null;
		try {
			File file1 = MultipartFileToFile.multipartFileToFile(file);
			//后缀
			map.put("fileType", FileUtil.extName(file1));
			accessFilePath = ftpUtils.uploadImage(path, FileUtil.extName(file1), file1);
			MultipartFileToFile.delteTempFile(file1);
		} catch (Exception e) {
			e.printStackTrace();
			json.setSuccess(false);
			json.setMsg("上传失败!");
			return json;
		}
		map.put("fileSize",file.getSize());
		map.put("fileUrl",accessFilePath);
		map.put("fileName",file.getOriginalFilename());
		json.setSuccess(true);
		json.setMsg("上传成功");
		json.setData(map);
		return json;
	}

	/**
	 * APK文件上传
	 */
	@SysLog("APK文件上传")
	@RequestMapping("/uploadAPK")
	public ReturnJson uploadAPK(@RequestParam("file") MultipartFile file) {
		//图片上传
		String path = "/";
		ReturnJson json = new ReturnJson();
		Map<String,Object> map = new HashMap<>();
		String accessFilePath = null;
		try {
			//File file1 = MultipartFileToFile.multipartFileToFile(file);
			//map.put("fileType", FileUtil.extName(file1));
			//accessFilePath = ftpUtils.uploadImage(path, FileUtil.extName(file1), file1);
			String substring = file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf(".") + 1);
			//后缀
			map.put("fileType", substring);
			if (file != null) {
				InputStream inputStream = file.getInputStream();
				FileInputStream fins = (FileInputStream) inputStream;
				accessFilePath = ftpUtils.defaultUploadNoRestFileName(path, file.getOriginalFilename(), fins);
			}
		} catch (Exception e) {
			e.printStackTrace();
			json.setSuccess(false);
			json.setMsg("上传失败!");
			return json;
		}
		map.put("fileSize",file.getSize());
		map.put("fileUrl",accessFilePath);
		map.put("fileName",file.getOriginalFilename());
		json.setSuccess(true);
		json.setMsg("上传成功");
		json.setData(map);
		return json;
	}

	/**
	 * APK分页列表
	 */
	@RequestMapping("/pageForAPK")
	public R pageForAPK(Page page, SysFileDto sysFileDto){
		return R.ok().put("page", sysFileServiceRemote.pageForAPK(page,sysFileDto));
	}

	





}
