
package io.platform.sys.web.controller.rest;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.sys.dto.SysLogDto;
import io.platform.sys.web.remote.SysLogServiceRemote;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/log")
public class SysLogRestController extends AbstractController {

    @Autowired
    private SysLogServiceRemote sysLogServiceRemote;

    /**
     * 所有列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("sys:log:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", sysLogServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @RequestMapping("/page")
    @RequiresPermissions("sys:log:page")
    public R page(Page<SysLogDto> page, SysLogDto sysLogDto) {

        return R.ok().put("page", sysLogServiceRemote.getPage(page, sysLogDto));
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("sys:log:info")
    public R info(@PathVariable("id") Long id) {
        SysLogDto sysLogDto = sysLogServiceRemote.getOne(id);
        return R.ok().put("sysLogDto", sysLogDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @RequestMapping("/save")
    @RequiresPermissions("sys:log:save")
    public R save(@RequestBody SysLogDto sysLogDto) {
        ValidatorUtils.validateEntity(sysLogDto);
        ExecuteResult<String> result = sysLogServiceRemote.save(sysLogDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @RequestMapping("/update")
    @RequiresPermissions("sys:sysLog:update")
    public R update(@RequestBody SysLogDto sysLogDto) {
        ValidatorUtils.validateEntity(sysLogDto);
        ExecuteResult<String> result = sysLogServiceRemote.update(sysLogDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @RequestMapping("/delete")
    @RequiresPermissions("sys:sysLog:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = sysLogServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
