
package io.platform.sys.web.controller.rest;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.sys.dto.SysMessageDto;
import io.platform.sys.web.remote.SysMessageServiceRemote;
import org.springframework.web.bind.annotation.*;

import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;


import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/sysMessage")
public class SysMessageRestController extends AbstractController {

    @Autowired
	private SysMessageServiceRemote sysMessageServiceRemote;
	
	/**
	 * 所有列表
	 */
	@RequestMapping("/list")
	@RequiresPermissions("sys:sysMessage:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", sysMessageServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@RequestMapping("/page")
	@RequiresPermissions("sys:sysMessage:page")
	public R page(Page page, SysMessageDto sysMessageDto){
		return R.ok().put("page", sysMessageServiceRemote.getPage(page,sysMessageDto));
	}
	/**
	 * 信息
	 */
	@RequestMapping("/info/{id}")
	@RequiresPermissions("sys:sysMessage:info")
	public R info(@PathVariable("id") Long id){
		SysMessageDto sysMessageDto = sysMessageServiceRemote.getOne(id);
		return R.ok().put("sysMessageDto", sysMessageDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@RequestMapping("/save")
	@RequiresPermissions("sys:sysMessage:save")
	public R save(@RequestBody SysMessageDto sysMessageDto){
		String username = getUser().getUsername();
		Long userId = getUserId();
		ValidatorUtils.validateEntity(sysMessageDto);
        ExecuteResult<String> result= sysMessageServiceRemote.save(sysMessageDto,username,userId);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@RequestMapping("/update")
	@RequiresPermissions("sys:sysMessage:edit")
	public R update(@RequestBody SysMessageDto sysMessageDto){
        ValidatorUtils.validateEntity(sysMessageDto);
        ExecuteResult<String> result= sysMessageServiceRemote.update(sysMessageDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@RequestMapping("/delete")
	@RequiresPermissions("sys:sysMessage:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= sysMessageServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

}
