package io.platform.sys.web.controller.rest;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.sys.dto.SysMetaCityDto;
import io.platform.sys.web.remote.SysMetaCityServiceRemote;

import org.apache.shiro.authz.annotation.RequiresPermissions;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/sys/sysMetaCity")
public class SysMetaCityRestController extends AbstractController {

    @Autowired
	private SysMetaCityServiceRemote sysMetaCityServiceRemote;
	
	/**
	 * 所有列表
	 */
	@RequestMapping("/list")
	@RequiresPermissions("sys:sysMetaCity:list")
	public R list(@RequestBody String s){
		Map<String,Object> params= (Map) JSON.parse(s);
		if (params.get("t") != null || !"".equals(params.get("t"))) {
			params.remove("t");
		}
		//查询列表数据
		return R.ok().put("list", sysMetaCityServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@RequestMapping("/page")
	@RequiresPermissions("sys:sysMetaCity:page")
	public R page(Page<SysMetaCityDto> page,SysMetaCityDto sysMetaCityDto){
		return R.ok().put("page", sysMetaCityServiceRemote.getPage(page,sysMetaCityDto));
	}
	/**
	 * 信息
	 */
	@RequestMapping("/info/{id}")
	@RequiresPermissions("sys:sysMetaCity:info")
	public R info(@PathVariable("id") Long id){
		SysMetaCityDto sysMetaCityDto = sysMetaCityServiceRemote.getOne(id);
		return R.ok().put("sysMetaCityDto", sysMetaCityDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@RequestMapping("/save")
	@RequiresPermissions("sys:sysMetaCity:save")
	public R save(@RequestBody SysMetaCityDto sysMetaCityDto){
        ValidatorUtils.validateEntity(sysMetaCityDto);
        ExecuteResult<String> result= sysMetaCityServiceRemote.save(sysMetaCityDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@RequestMapping("/update")
	@RequiresPermissions("sys:sysMetaCity:edit")
	public R update(@RequestBody SysMetaCityDto sysMetaCityDto){
        ValidatorUtils.validateEntity(sysMetaCityDto);
        ExecuteResult<String> result= sysMetaCityServiceRemote.update(sysMetaCityDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@RequestMapping("/delete")
	@RequiresPermissions("sys:sysMetaCity:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= sysMetaCityServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

}
