package io.platform.sys.web.controller.rest;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;

import io.platform.sys.dto.SysMetaProvinceDto;
import io.platform.sys.web.remote.SysMetaProvinceServiceRemote;

import org.apache.shiro.authz.annotation.RequiresPermissions;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/sys/sysMetaProvince")
public class SysMetaProvinceRestController extends AbstractController {

    @Autowired
	private SysMetaProvinceServiceRemote sysMetaProvinceServiceRemote;
	
	/**
	 * 所有列表
	 */
	@RequestMapping("/list")
	@RequiresPermissions("sys:sysMetaProvince:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", sysMetaProvinceServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@RequestMapping("/page")
	@RequiresPermissions("sys:sysMetaProvince:page")
	public R page(Page<SysMetaProvinceDto> page, SysMetaProvinceDto sysMetaProvinceDto){
		return R.ok().put("page", sysMetaProvinceServiceRemote.getPage(page,sysMetaProvinceDto));
	}
	/**
	 * 信息
	 */
	@RequestMapping("/info/{id}")
	@RequiresPermissions("sys:sysMetaProvince:info")
	public R info(@PathVariable("id") Long id){
		SysMetaProvinceDto sysMetaProvinceDto = sysMetaProvinceServiceRemote.getOne(id);
		return R.ok().put("sysMetaProvinceDto", sysMetaProvinceDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@RequestMapping("/save")
	@RequiresPermissions("sys:sysMetaProvince:save")
	public R save(@RequestBody SysMetaProvinceDto sysMetaProvinceDto){
        ValidatorUtils.validateEntity(sysMetaProvinceDto);
        ExecuteResult<String> result= sysMetaProvinceServiceRemote.save(sysMetaProvinceDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@RequestMapping("/update")
	@RequiresPermissions("sys:sysMetaProvince:edit")
	public R update(@RequestBody SysMetaProvinceDto sysMetaProvinceDto){
        ValidatorUtils.validateEntity(sysMetaProvinceDto);
        ExecuteResult<String> result= sysMetaProvinceServiceRemote.update(sysMetaProvinceDto);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@RequestMapping("/delete")
	@RequiresPermissions("sys:sysMetaProvince:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= sysMetaProvinceServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        return R.ok(result.getSuccessMessage());
        }else{
        return R.error(result.getErrorMessages().get(0));
        }
	}

	// 获取省市列表
	@RequestMapping("/getProvinceAndCity")
	public R getProvinceAndCity() {
		//查询列表数据
		return R.ok().put("list", sysMetaProvinceServiceRemote.getProvinceAndCity());
	}

}
