
package io.platform.sys.web.controller.rest;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.FtpUtils;
import io.platform.base.common.utils.MultipartFileToFile;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.oss.dto.SysOssDto;
import io.platform.sys.web.remote.SysOssServiceRemote;
import org.apache.commons.io.FileUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/oss")
public class SysOssRestController extends AbstractController {

    @Autowired
    private SysOssServiceRemote sysOssServiceRemote;

    /**
     * 所有列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("sys:oss:all")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", sysOssServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @RequestMapping("/page")
    @RequiresPermissions("sys:oss:all")
    public R page(Page<SysOssDto> page, SysOssDto sysOssDto) {

        return R.ok().put("page", sysOssServiceRemote.getPage(page, sysOssDto));
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("sys:oss:all")
    public R info(@PathVariable("id") Long id) {
        SysOssDto sysOssDto = sysOssServiceRemote.getOne(id);
        return R.ok().put("sysOssDto", sysOssDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @RequestMapping("/save")
    @RequiresPermissions("sys:oss:all")
    public R save(@RequestBody SysOssDto sysOssDto) {
        ValidatorUtils.validateEntity(sysOssDto);
        ExecuteResult<String> result = sysOssServiceRemote.save(sysOssDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @RequestMapping("/update")
    @RequiresPermissions("sys:oss:all")
    public R update(@RequestBody SysOssDto sysOssDto) {
        ValidatorUtils.validateEntity(sysOssDto);
        ExecuteResult<String> result = sysOssServiceRemote.update(sysOssDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @RequestMapping("/delete")
    @RequiresPermissions("sys:oss:all")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = sysOssServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }




}
