
package io.platform.sys.web.controller.rest;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.sys.dto.SysRoleMenuDto;
import io.platform.sys.web.remote.SysRoleMenuServiceRemote;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/sysRoleMenu")
public class SysRoleMenuRestController extends AbstractController {

    @Autowired
    private SysRoleMenuServiceRemote sysRoleMenuServiceRemote;

    /**
     * 所有列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("sys:sysRoleMenu:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", sysRoleMenuServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @RequestMapping("/page")
    @RequiresPermissions("sys:sysRoleMenu:page")
    public R page(Page<SysRoleMenuDto> page, SysRoleMenuDto sysRoleMenuDto) {

        return R.ok().put("page", sysRoleMenuServiceRemote.getPage(page, sysRoleMenuDto));
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("sys:sysRoleMenu:info")
    public R info(@PathVariable("id") Long id) {
        SysRoleMenuDto sysRoleMenuDto = sysRoleMenuServiceRemote.getOne(id);
        return R.ok().put("sysRoleMenuDto", sysRoleMenuDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @RequestMapping("/save")
    @RequiresPermissions("sys:sysRoleMenu:save")
    public R save(@RequestBody SysRoleMenuDto sysRoleMenuDto) {
        ValidatorUtils.validateEntity(sysRoleMenuDto);
        ExecuteResult<String> result = sysRoleMenuServiceRemote.save(sysRoleMenuDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @RequestMapping("/update")
    @RequiresPermissions("sys:sysRoleMenu:update")
    public R update(@RequestBody SysRoleMenuDto sysRoleMenuDto) {
        ValidatorUtils.validateEntity(sysRoleMenuDto);
        ExecuteResult<String> result = sysRoleMenuServiceRemote.update(sysRoleMenuDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @RequestMapping("/delete")
    @RequiresPermissions("sys:sysRoleMenu:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = sysRoleMenuServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
