
package io.platform.sys.web.controller.rest;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.Constant;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.sys.dto.SysRoleDto;
import io.platform.sys.web.remote.SysRoleServiceRemote;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/role")
public class SysRoleRestController extends AbstractController {

    @Autowired
    private SysRoleServiceRemote sysRoleServiceRemote;

    /**
     * 所有列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("sys:role:list")
    public R list(Page<SysRoleDto> page, SysRoleDto sysRoleDto) {

        //查询列表数据
        //如果不是超级管理员，则只查询自己创建的角色列表
        if (getUserId() != Constant.SUPER_ADMIN) {
            sysRoleDto.setCreateUserId(getUserId());
        }

        return R.ok().put("page", sysRoleServiceRemote.getPage(page, sysRoleDto));
    }

    /**
     * 分页列表
     */
    @RequestMapping("/page")
    @RequiresPermissions("sys:role:page")
    public R page(Page<SysRoleDto> page, SysRoleDto sysRoleDto) {

        return R.ok().put("page", sysRoleServiceRemote.getPage(page, sysRoleDto));
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("sys:role:info")
    public R info(@PathVariable("id") Long id) {
        SysRoleDto sysRoleDto = sysRoleServiceRemote.getOne(id);
        return R.ok().put("role", sysRoleDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @RequestMapping("/save")
    @RequiresPermissions("sys:role:save")
    public R save(@RequestBody SysRoleDto sysRoleDto) {
        ValidatorUtils.validateEntity(sysRoleDto);

        ExecuteResult<String> result = sysRoleServiceRemote.save(sysRoleDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @RequestMapping("/update")
    @RequiresPermissions("sys:role:update")
    public R update(@RequestBody SysRoleDto sysRoleDto) {
        ValidatorUtils.validateEntity(sysRoleDto);
        ExecuteResult<String> result = sysRoleServiceRemote.update(sysRoleDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @RequestMapping("/delete")
    @RequiresPermissions("sys:role:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = sysRoleServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 角色列表
     */
    @GetMapping("/select")
    @RequiresPermissions("sys:role:select")
    public R select() {
        Map<String, Object> map = new HashMap<>();

        //如果不是超级管理员，则只查询自己所拥有的角色列表
        if (getUserId() != Constant.SUPER_ADMIN) {
            map.put("create_user_id", getUserId());
        }
        List<SysRoleDto> list = sysRoleServiceRemote.getList(map);

        return R.ok().put("list", list);
    }

}
