
package io.platform.sys.web.controller.rest;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.sys.dto.SysSmsLogDto;
import io.platform.sys.web.remote.SysSmsLogServiceRemote;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/sysSmsLog")
public class SysSmsLogRestController extends AbstractController {

    @Autowired
    private SysSmsLogServiceRemote sysSmsLogServiceRemote;

    /**
     * 所有列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("sys:sysSmsLog:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", sysSmsLogServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @RequestMapping("/page")
    @RequiresPermissions("sys:sysSmsLog:page")
    public R page(Page page, SysSmsLogDto sysSmsLogDto) {
        return R.ok().put("page", sysSmsLogServiceRemote.getPage(page, sysSmsLogDto));
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("sys:sysSmsLog:info")
    public R info(@PathVariable("id") Long id) {
        SysSmsLogDto sysSmsLogDto = sysSmsLogServiceRemote.getOne(id);
        return R.ok().put("sysSmsLogDto", sysSmsLogDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @RequestMapping("/save")
    @RequiresPermissions("sys:sysSmsLog:save")
    public R save(@RequestBody SysSmsLogDto sysSmsLogDto) {
        ValidatorUtils.validateEntity(sysSmsLogDto);
        ExecuteResult<String> result = sysSmsLogServiceRemote.save(sysSmsLogDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @RequestMapping("/update")
    @RequiresPermissions("sys:sysSmsLog:edit")
    public R update(@RequestBody SysSmsLogDto sysSmsLogDto) {
        ValidatorUtils.validateEntity(sysSmsLogDto);
        ExecuteResult<String> result = sysSmsLogServiceRemote.update(sysSmsLogDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @RequestMapping("/delete")
    @RequiresPermissions("sys:sysSmsLog:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = sysSmsLogServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
