
package io.platform.sys.web.controller.rest;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.sys.dto.SysUserRoleDto;
import io.platform.sys.web.remote.SysUserRoleServiceRemote;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/sysUserRole")
public class SysUserRoleRestController extends AbstractController {

    @Autowired
    private SysUserRoleServiceRemote sysUserRoleServiceRemote;

    /**
     * 所有列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("sys:sysUserRole:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", sysUserRoleServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @RequestMapping("/page")
    @RequiresPermissions("sys:sysUserRole:page")
    public R page(Page<SysUserRoleDto> page, SysUserRoleDto sysUserRoleDto) {

        return R.ok().put("page", sysUserRoleServiceRemote.getPage(page, sysUserRoleDto));
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("sys:sysUserRole:info")
    public R info(@PathVariable("id") Long id) {
        SysUserRoleDto sysUserRoleDto = sysUserRoleServiceRemote.getOne(id);
        return R.ok().put("sysUserRoleDto", sysUserRoleDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @RequestMapping("/save")
    @RequiresPermissions("sys:sysUserRole:save")
    public R save(@RequestBody SysUserRoleDto sysUserRoleDto) {
        ValidatorUtils.validateEntity(sysUserRoleDto);
        ExecuteResult<String> result = sysUserRoleServiceRemote.save(sysUserRoleDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @RequestMapping("/update")
    @RequiresPermissions("sys:sysUserRole:update")
    public R update(@RequestBody SysUserRoleDto sysUserRoleDto) {
        ValidatorUtils.validateEntity(sysUserRoleDto);
        ExecuteResult<String> result = sysUserRoleServiceRemote.update(sysUserRoleDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @RequestMapping("/delete")
    @RequiresPermissions("sys:sysUserRole:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = sysUserRoleServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
