
package io.platform.sys.web.controller.rest;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.sys.dto.SysUserTokenDto;
import io.platform.sys.web.remote.SysUserTokenServiceRemote;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/sys/user/token")
public class SysUserTokenRestController extends AbstractController {

    @Autowired
    private SysUserTokenServiceRemote sysUserTokenServiceRemote;

    /**
     * 所有列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("sys:sysUserToken:list")
    public R list(@RequestParam Map<String, Object> params) {
        //查询列表数据
        return R.ok().put("list", sysUserTokenServiceRemote.getList(params));
    }

    /**
     * 分页列表
     */
    @RequestMapping("/page")
    @RequiresPermissions("sys:sysUserToken:page")
    public R page(Page<SysUserTokenDto> page, SysUserTokenDto sysUserTokenDto) {

        return R.ok().put("page", sysUserTokenServiceRemote.getPage(page, sysUserTokenDto));
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("sys:sysUserToken:info")
    public R info(@PathVariable("id") Long id) {
        SysUserTokenDto sysUserTokenDto = sysUserTokenServiceRemote.getOne(id);
        return R.ok().put("sysUserTokenDto", sysUserTokenDto);
    }

    /**
     * 保存
     */
    @SysLog("保存")
    @RequestMapping("/save")
    @RequiresPermissions("sys:sysUserToken:save")
    public R save(@RequestBody SysUserTokenDto sysUserTokenDto) {
        ValidatorUtils.validateEntity(sysUserTokenDto);
        ExecuteResult<String> result = sysUserTokenServiceRemote.save(sysUserTokenDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 修改
     */
    @SysLog("修改")
    @RequestMapping("/update")
    @RequiresPermissions("sys:sysUserToken:update")
    public R update(@RequestBody SysUserTokenDto sysUserTokenDto) {
        ValidatorUtils.validateEntity(sysUserTokenDto);
        ExecuteResult<String> result = sysUserTokenServiceRemote.update(sysUserTokenDto);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

    /**
     * 删除
     */
    @SysLog("删除")
    @RequestMapping("/delete")
    @RequiresPermissions("sys:sysUserToken:delete")
    public R delete(@RequestBody List<Long> ids) {
        ExecuteResult<String> result = sysUserTokenServiceRemote.deleteBatch(ids);
        if (result.isSuccess()) {
            return R.ok(result.getSuccessMessage());
        } else {
            return R.error(result.getErrorMessages().get(0));
        }
    }

}
