
package io.platform.sys.web.remote;

import com.alibaba.dubbo.config.annotation.Reference;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.utils.Constant;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.ShiroUtils;
import io.platform.sys.dto.SysMenuDto;
import io.platform.sys.dto.SysUserDto;
import io.platform.sys.service.client.api.SysMenuServiceClient;
import io.platform.sys.service.client.api.SysUserServiceClient;
import org.apache.commons.lang.StringUtils;
import org.apache.shiro.crypto.hash.Sha256Hash;
import org.springframework.stereotype.Service;

import java.util.*;


/**
 * Created by sevelli on 2017/8/31.
 */
@Service("sysUserServiceRemote")
public class SysUserServiceRemote {

    @Reference(check = false)
    private SysUserServiceClient sysUserServiceClient;
    @Reference(check = false)
    private SysMenuServiceClient sysMenuServiceClient;

    public List<String> queryAllPerms(Long userId) {
        return sysUserServiceClient.queryAllPerms(userId);
    }

    /**
     * 根据参数获取列表  无分页
     */
    public List<SysUserDto> getList(Map<String, Object> params) {
        return sysUserServiceClient.queryList(params);
    }

    /**
     * 根据参数进行 分页查询
     */
    public Page<SysUserDto> getPage(Page<SysUserDto> page, SysUserDto sysUserDto) {
        return sysUserServiceClient.getPage(page, sysUserDto);
    }

    /**
     * 根据主键 获取单条数据明细
     */
    public SysUserDto getOne(Long id) {
        SysUserDto sysUserDto = sysUserServiceClient.queryObject(id);

        return sysUserDto;
    }

    /**
     * 保存 数据
     */
    public ExecuteResult<String> save(SysUserDto sysUserDto) {

        sysUserDto.setSalt(getUUID());
        String pwd = new Sha256Hash(sysUserDto.getPassword(), sysUserDto.getSalt()).toHex();
        sysUserDto.setPassword(pwd);
        sysUserDto.setCreateTime(new Date());
        sysUserDto.setCreateUserId(ShiroUtils.getUserId());
        return sysUserServiceClient.save(sysUserDto);
    }

    /**
     * 修改单条数据
     */
    public ExecuteResult<String> update(SysUserDto sysUserDto) {

        return sysUserServiceClient.update(sysUserDto);
    }

    /**
     * 批量删除
     */
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        return sysUserServiceClient.deleteBatch(ids);
    }


    public SysUserDto queryByUserName(String username) {
        return sysUserServiceClient.selectByUserName(username);
    }

    public boolean updatePassword(Long userId, String password, String newPassword) {
        return sysUserServiceClient.updatePassword(userId, password, newPassword);
    }

    public Set<String> getUserPermissions(Long userId) {
        List<String> permsList;

        //系统管理员，拥有最高权限
        if (userId == Constant.SUPER_ADMIN) {
            List<SysMenuDto> menuList = sysMenuServiceClient.queryAllList();
            permsList = new ArrayList<>();
            if (menuList != null && menuList.size() > 0) {
                menuList.forEach(m -> permsList.add(m.getPerms()));
            } else {
                System.out.println("userId = [" + userId + "]");
            }

        } else {
            permsList = sysUserServiceClient.queryAllPerms(userId);
        }
        //用户权限列表
        Set<String> permsSet = new HashSet<>();
        for (String perms : permsList) {
            if (StringUtils.isBlank(perms)) {
                continue;
            }
            permsSet.addAll(Arrays.asList(perms.trim().split(",")));
        }
        return permsSet;
    }

    public static String getUUID() {
        String uuid = UUID.randomUUID().toString().trim().replaceAll("-", "");
        return uuid;
    }
}
