
package io.platform.sys.web.remote;

import com.alibaba.dubbo.config.annotation.Reference;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.oauth2.TokenGenerator;
import io.platform.sys.dto.SysUserTokenDto;
import io.platform.sys.service.client.api.SysUserTokenServiceClient;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;


/**
 * Created by sevelli on 2017/8/31.
 */
@Service("sysUserTokenServiceRemote")
public class SysUserTokenServiceRemote {
    //12小时后过期
    private final static int EXPIRE = 3600 * 12;

    @Reference(check = false)
    private SysUserTokenServiceClient sysUserTokenServiceClient;

    /**
     * 根据参数获取列表  无分页
     */
    public List<SysUserTokenDto> getList(Map<String, Object> params) {
        return sysUserTokenServiceClient.queryList(params);
    }

    /**
     * 根据参数进行 分页查询
     */
    public Page<SysUserTokenDto> getPage(Page<SysUserTokenDto> page, SysUserTokenDto sysUserTokenDto) {
        return sysUserTokenServiceClient.getPage(page, sysUserTokenDto);
    }

    /**
     * 根据主键 获取单条数据明细
     */
    public SysUserTokenDto getOne(Long id) {
        SysUserTokenDto sysUserTokenDto = sysUserTokenServiceClient.queryObject(id);
        return sysUserTokenDto;
    }

    /**
     * 保存 数据
     */
    public ExecuteResult<String> save(SysUserTokenDto sysUserTokenDto) {

        return sysUserTokenServiceClient.save(sysUserTokenDto);
    }

    /**
     * 修改单条数据
     */
    public ExecuteResult<String> update(SysUserTokenDto sysUserTokenDto) {

        return sysUserTokenServiceClient.update(sysUserTokenDto);
    }

    /**
     * 批量删除
     */
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        return sysUserTokenServiceClient.deleteBatch(ids);
    }


    public SysUserTokenDto queryByToken(String token) {
        return sysUserTokenServiceClient.selectOne(token);
    }

    public R createToken(Long userId) {
        //生成一个token
        String token = TokenGenerator.generateValue();

        //当前时间
        Date now = new Date();
        //过期时间
        Date expireTime = new Date(now.getTime() + EXPIRE * 1000);

        //判断是否生成过token
        SysUserTokenDto tokenEntity = sysUserTokenServiceClient.queryObject(userId);
        if (tokenEntity == null) {
            tokenEntity = new SysUserTokenDto();
            tokenEntity.setUserId(userId);
            tokenEntity.setToken(token);
            tokenEntity.setUpdateTime(now);
            tokenEntity.setExpireTime(expireTime);

            //保存token
            sysUserTokenServiceClient.save(tokenEntity);
        } else {
            tokenEntity.setToken(token);
            tokenEntity.setUpdateTime(now);
            tokenEntity.setExpireTime(expireTime);

            //更新token
            sysUserTokenServiceClient.update(tokenEntity);
        }

        R r = R.ok().put("token", token).put("expire", EXPIRE);

        return r;
    }

    public void logout(Long userId) {
        //生成一个token
        String token = TokenGenerator.generateValue();

        //修改token
        SysUserTokenDto tokenEntity = new SysUserTokenDto();
        tokenEntity.setUserId(userId);
        tokenEntity.setToken(token);
        sysUserTokenServiceClient.update(tokenEntity);
    }
}
