package io.platform.base.common.aspect;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Date;

import javax.servlet.ServletInputStream;
import javax.servlet.http.HttpServletRequest;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.Signature;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.reflect.MethodSignature;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import com.alibaba.fastjson.JSONObject;
import io.platform.base.common.annotation.CountUse;
import io.platform.base.common.utils.HttpRequest;

/**
* 做一个切面类，主要作用就是对接口的请求进行拦截
* 拦截的方式，在指定接口方法上面加上@CountUse注解即可
* @author zhuxinyu
*/
@Aspect
@Component
public class RequestAspect {
	
	private Logger logger = LoggerFactory.getLogger(RequestAspect.class);
	
//	@Autowired
//	private SysOpreaLogServiceClient client;
	
   /**
    * 在执行被@CountUse注解修饰的方法之前 会执行doBefore()方法
    * @param joinPoint 连接点，就是被拦截点
    */
   @Before(value = "@annotation(io.platform.base.common.annotation.CountUse)")
   public void doBefore(JoinPoint joinPoint) {
       //获取到请求的属性
       ServletRequestAttributes attributes =
               (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
       HttpServletRequest request = attributes.getRequest();
       
       //获取到所有的参数值的数组
       Object[] args = joinPoint.getArgs();
       Signature signature = joinPoint.getSignature();
       MethodSignature methodSignature = (MethodSignature) signature;
       //获取到方法的所有参数名称的字符串数组
       String[] parameterNames = methodSignature.getParameterNames();
       Method method = methodSignature.getMethod();
       //自定义参数
       CountUse countUse = (CountUse)method.getAnnotation(CountUse.class);
//       logger.info("自定义注解 fundesc:" + countUse.fundesc());
//       logger.info("自定义注解 username:" + countUse.username());
//       //根据请求对象拿到访问的地址
//       logger.info("##url=" + request.getRequestURL());
//       //获取是Get还是Post请求
//       logger.info("##method=" + request.getMethod());
//       //ip获取到访问
//       logger.info("##ip=" + request.getRemoteAddr());
//       //获取被拦截的类名和方法名
//       logger.info("##类名= " + joinPoint.getSignature().getDeclaringTypeName() + "  ###方法=" + joinPoint.getSignature().getName());
       
       try {
//    	   ServletInputStream inputStream = request.getInputStream();
//           BufferedReader reader = new BufferedReader(new InputStreamReader(inputStream));
//           StringBuilder requestBuilder = new StringBuilder();
//           String inputStr;
//           while ((inputStr = reader.readLine()) != null) {
//               requestBuilder.append(inputStr);
//           }
//           logger.info("##请求参数: " + requestBuilder.toString());
//           //原始参数对象数组
//           logger.info("##参数1=" + joinPoint.getArgs());
//           logger.info("##参数2=" + Arrays.toString(joinPoint.getArgs()) );
           
           //http-rest-dubbo
           JSONObject saveObj = new JSONObject();
	   	   saveObj.put("operation", countUse.fundesc());
   		   saveObj.put("methodname", "类名" + joinPoint.getSignature().getDeclaringTypeName() + " 方法" + joinPoint.getSignature().getName());
   		   saveObj.put("paramsname", Arrays.toString(joinPoint.getArgs()) );
   		   saveObj.put("ipname", request.getRemoteAddr() );
   		   saveObj.put("username", countUse.username() );
   		   saveObj.put("createdate", new Date() );

   		   //判断当前的操作系统
	   	   String os = System.getProperty("os.name"); 
		   if(os.toLowerCase().startsWith("win")){
			  //windows系统本地测试
			  //web-rest
	   		  HttpRequest.post(saveObj, "http://127.0.0.1:9002/sailun/sysOpreaLog/save");
		   }else {
			   //linux操作系统
			   //web-rest
	   		   HttpRequest.post(saveObj, "http://10.97.1.121:9002/sailun/sysOpreaLog/save");
		   }
           
		} catch (Exception e) {
			e.printStackTrace();
		}
   }
   
}
