package io.platform.base.common.utils;

import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

import org.apache.http.Consts;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.HttpStatus;
import org.apache.http.NameValuePair;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.InputStreamEntity;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;

import com.alibaba.fastjson.JSONObject;

/**
 * 使用
 * 
 */
public final class HttpRequest {

	private static int connectTimeout = 10000;
	private static int connectionRequestTimeout = 5000;
	private static int socketTimeout = 10000;

	private final static CloseableHttpClient client = HttpClients.createDefault();
	private static RequestConfig config = null;

	/**
	 * 设置超时的时间
	 * 
	 * @param connectTimeout
	 *            建立连接时间，http三次握手
	 * @param connectionRequestTimeout
	 *            从连接池获取连接的时间
	 * @param socketTimeout
	 *            数据传输时间
	 * 
	 * @since 2018.12.12
	 * @author zhouhui
	 */
	public static void setTimeOut(int connectTimeout, int connectionRequestTimeout, int socketTimeout) {
		HttpRequest.connectTimeout = connectTimeout;
		HttpRequest.connectionRequestTimeout = connectionRequestTimeout;
		HttpRequest.socketTimeout = socketTimeout;
	}

	private static RequestConfig requestConfig() {
		if(config != null){
			return config;
		}
		config = RequestConfig.custom()
				.setConnectTimeout(connectTimeout)
				.setConnectionRequestTimeout(connectionRequestTimeout)
				.setSocketTimeout(socketTimeout).build();
		return config;
	}

	/**
	 * HTTP GET请求  默认使用配置文件
	 * @param url 请求的地址
	 * @return HttpResponseBody 返回处理的结果
	 * 
	 * @since 2018.12.12
	 * @author zhouhui
	 * */
	public static HttpResponseBody requestGetByUrl(String url) {
		HashMap<String, String> headers = new HashMap<String, String>();
		HttpResponseBody body = requestGetByUrl(url,headers,true);
		return body;
	}

	/**
	 * HTTP GET请求
	 * @param url 请求的地址
	 * @param isConfig 是否使用配置 true为使用
	 * @return HttpResponseBody 返回处理的结果
	 * 
	 * @since 2018.12.12
	 * @author zhouhui
	 * */
	public static HttpResponseBody requestGetByUrl(String url,HashMap<String, String> headers,boolean isConfig) {
		HttpGet httpGet = new HttpGet(url);
		if(headers.size() > 0){
			Iterator<String> keyIter = headers.keySet().iterator();
			while(keyIter.hasNext()){
				String key = keyIter.next();
				String value = headers.get(key);
				httpGet.setHeader(key,value);
			}
		}
		CloseableHttpResponse response = null;
		HttpResponseBody body = null;
		if (isConfig) {
			httpGet.setConfig(requestConfig());
		}
		try {
			response = client.execute(httpGet);
			body = new HttpResponseBody();
			body.setStatusCode(response.getStatusLine().getStatusCode());
			if(response.getEntity() != null){
				String strResponse = EntityUtils.toString(response.getEntity(), "UTF-8");
				body.setStrResponse(strResponse);
			}
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			if (response != null) {
				try {
					response.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		return body;
	}
	
	/**
	 * HTTP POST 通过form方式进行发送
	 * @param url 请求的地址
	 * @param option 参数的键值对
	 * @param isConfig 是否使用配置，true使用配置
	 * @return HttpResponseBody 返回处理的结果
	 * 
	 * @since 2018.12.12
	 * @author zhouhui
	 * */
	public static HttpResponseBody requestPostByForm(String url,HashMap<String, String> option,boolean isConfig){
		HttpPost httpPost = new HttpPost(url);
		if(isConfig){
			httpPost.setConfig(requestConfig());
		}
		int mapSize = option.size();
		if(mapSize > 0){
			List<NameValuePair> list = new ArrayList<NameValuePair>(mapSize);
			Iterator<String> keyIterator = option.keySet().iterator();
			while(keyIterator.hasNext()){
				String key = keyIterator.next();
				String value = option.get(key);
				list.add(new BasicNameValuePair(key, value));
			}
			HttpEntity reqEntity = null;
			try {
				reqEntity = new UrlEncodedFormEntity(list,Consts.UTF_8);
				httpPost.setEntity(reqEntity);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		CloseableHttpResponse response = null;
		HttpResponseBody body = new HttpResponseBody();
		try {
			response = client.execute(httpPost);
			body.setStatusCode(response.getStatusLine().getStatusCode());
			if(response.getEntity() != null){
				String strResponse = EntityUtils.toString(response.getEntity(), "UTF-8");
				body.setStrResponse(strResponse);
			}
		} catch (IOException e) {
			e.printStackTrace();
		}finally{
			if(response != null){
				try {
					response.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		return body;
	}
	
	/**
	 * HTTP POST 通过inputstream进行传输
	 * @param url 请求的地址
	 * @param headers 请求的头设置
	 * @param dataStr 请求的数据字符串
	 * @param encode 编码的格式
	 * @param isConfig 是否使用配置，true使用配置
	 * @return HttpResponseBody 返回处理的结果
	 * 
	 * @since 2018.12.12
	 * @author zhouhui
	 * */
	public static HttpResponseBody requestPostByStream(String url,
			HashMap<String, String> headers,
			String dataStr,
			String encode ,
			boolean isConfig){
		HttpPost httpPost = new HttpPost(url);
		if(headers.size() > 0){
			Iterator<String> keyIter = headers.keySet().iterator();
			while(keyIter.hasNext()){
				String key = keyIter.next();
				String value = headers.get(key);
				httpPost.setHeader(key,value);
			}
		}
		if(isConfig){
			httpPost.setConfig(requestConfig());
		}
		ByteArrayInputStream instream = null;
		try {
			instream = new ByteArrayInputStream(dataStr.getBytes(encode));
			InputStreamEntity entity = new InputStreamEntity(instream);
			httpPost.setEntity(entity);
		} catch (Exception e) {
			e.printStackTrace();
		}
		CloseableHttpResponse response = null;
		HttpResponseBody body = new HttpResponseBody();
		try {
			response = client.execute(httpPost);
			body.setStatusCode(response.getStatusLine().getStatusCode());
			if(response.getEntity() != null){
				String strResponse = EntityUtils.toString(response.getEntity(), "UTF-8");
				body.setStrResponse(strResponse);
			}
		} catch (IOException e) {
			e.printStackTrace();
		}finally{
			if(response != null){
				try {
					response.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		return body;
	}
	
	/**
	 * 发送post请求，请求格式是json,返回json结构
	 * @param url 请求的地址
	 * @param dataStr 数据字符串
	 * @param encode 编码格式
	 * @param isConfig 是否使用预先设置的配置
	 * @return 返回的结果
	 * 
	 * @author zhouhui
	 * @since 2020.05.19
	 */
	public static HttpResponseBody requestPostByJson(String url,
			String dataStr,
			String encode ,
			boolean isConfig){
		HttpPost httpPost = new HttpPost(url);
		httpPost.setHeader("Content-Type", "application/json;charset=utf-8");
		if(isConfig){
			httpPost.setConfig(requestConfig());
		}
		StringEntity se = new StringEntity(dataStr, Charset.forName("UTF-8"));
        httpPost.setEntity(se);
		CloseableHttpResponse response = null;
		HttpResponseBody body = new HttpResponseBody();
		try {
			response = client.execute(httpPost);
			body.setStatusCode(response.getStatusLine().getStatusCode());
			body.setResContentType(response.getEntity().getContentType().getValue());
			if(response.getEntity() != null){
				String strResponse = EntityUtils.toString(response.getEntity(), "UTF-8");
				body.setStrResponse(strResponse);
			}
		} catch (IOException e) {
			e.printStackTrace();
		}finally{
			if(response != null){
				try {
					response.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		return body;
	}
	
	/**
	 * 发送post请求，请求格式是json，返回字节流，也有可能返回字符串
	 * 根据返回的Content-Type判断一下类型
	 * @param url 请求的地址
	 * @param dataStr 数据字符串
	 * @param encode 编码格式
	 * @param isConfig 是否使用预先设置的配置
	 * @return 返回的结果
	 * 
	 * @author zhouhui
	 * @since 2020.05.19
	 */
	public static HttpResponseBody requestPostByJsonGetSteam(String url,
			String dataStr,
			String encode ,
			boolean isConfig){
		HttpPost httpPost = new HttpPost(url);
		httpPost.setHeader("Content-Type", "application/json;charset=utf-8");
		if(isConfig){
			httpPost.setConfig(requestConfig());
		}
		StringEntity se = new StringEntity(dataStr, Charset.forName("UTF-8"));
        httpPost.setEntity(se);
		CloseableHttpResponse response = null;
		HttpResponseBody body = new HttpResponseBody();
		try {
			response = client.execute(httpPost);
			body.setStatusCode(response.getStatusLine().getStatusCode());
			String contentType = response.getEntity().getContentType().getValue();
			body.setResContentType(contentType);
			if(response.getEntity() != null){
				if(contentType.indexOf("image") >= 0) {
					InputStream inputStream = response.getEntity().getContent();
					body.setBytes(is2ByeteArray(inputStream));
				}else {
					String strResponse = EntityUtils.toString(response.getEntity(), "UTF-8");
					body.setStrResponse(strResponse);
				}
			}
		} catch (IOException e) {
			e.printStackTrace();
		}finally{
			if(response != null){
				try {
					response.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		return body;
	}
	
	/**
	 * 将inputStream转成byte数组
	 * @param is 输入的字节流
	 * @return byte[] byte数组
	 * @throws IOException
	 * 
	 * @author zhouhui
	 * @since 2020.05.19
	 */
	private static byte[] is2ByeteArray(InputStream input) throws IOException {
		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		byte[] buff = new byte[100];
		int rc = 0;
		while((rc=input.read(buff, 0, 100))>0) {
			baos.write(buff, 0, rc);
		}
		return baos.toByteArray();
	}

	
	/**
	 * HTTP POST 通过inputstream进行传输 
	 * header 使用Content-Type=application/x-www-form-urlencoded；
	 * 编码格式使用UTF-8
	 * 
	 * @param url 请求的地址
	 * @param dataStr 请求的数据字符串
	 * @return HttpResponseBody 返回处理的结果
	 * 
	 * @since 2018.12.12
	 * @author zhouhui
	 * */
	public static HttpResponseBody requestPostByStream(String url,String dataStr){
		HashMap<String, String> headers = new HashMap<String, String>();
		headers.put("Content-Type","application/x-www-form-urlencoded");
		HttpResponseBody body = requestPostByStream(url, headers, dataStr, "UTF-8", true);
		return body;
	}
	
	public static void main(String[] args) {
//		String url = "http://192.168.209.128:8050/OtherWebServer/Controller/AliyunSMS.asmx/SendSMS";
//		String dataStr = "";
//		dataStr += "token=sailunsmstest";
//		dataStr += "&phone=18765925334";
//		dataStr += "&sign=赛轮集团";
//		dataStr += "&type=SMS_134585053";
//		dataStr += "&sms={code:2334}";
//		HashMap<String, String> headers = new HashMap<String, String>();
//		headers.put("Content-Type","application/x-www-form-urlencoded");
//		HttpResponseBody body = HttpRequest.requestPostByStream(url,headers,dataStr,"UTF-8", true);
//		System.out.println(body.getStatusCode());
//		System.out.println(body.getStrResponse());
		
//		String url = "https://api.yonyoucloud.com/apis/dst/baseinfo/baseinfoV3?id=&name=淘宝网";
//		HashMap<String, String> headers = new HashMap<String, String>();
//		headers.put("apicode", "d7a7c2aef9054918b624fe1c895dd8ea");
//		HttpResponseBody body = HttpRequest.requestGetByUrl(url,headers,true);
//		System.out.println(body.getStatusCode());
//		System.out.println(body.getStrResponse());
	}
	
	public static String post(JSONObject json, String url){
		String result = "";
		HttpPost post = new HttpPost(url);
		try{
			CloseableHttpClient httpClient = HttpClients.createDefault();
        
			post.setHeader("Content-Type","application/json;charset=utf-8");
			post.addHeader("Authorization", "Basic YWRtaW46");
			StringEntity postingString = new StringEntity(json.toString(),"utf-8");
			post.setEntity(postingString);
			HttpResponse response = httpClient.execute(post);
			
			InputStream in = response.getEntity().getContent();
			BufferedReader br = new BufferedReader(new InputStreamReader(in, "utf-8"));
			StringBuilder strber= new StringBuilder();
			String line = null;
			while((line = br.readLine())!=null){
				strber.append(line+'\n');
			}
			br.close();
			in.close();
			result = strber.toString();
			if(response.getStatusLine().getStatusCode()!=HttpStatus.SC_OK){
				result = "服务器异常";
			}
		} catch (Exception e){
			System.out.println("请求异常");
			throw new RuntimeException(e);
		} finally{
			post.abort();
		}
		return result;
	}
}
