
package io.platform.oss.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.oss.biz.entity.SysOss;
import io.platform.oss.biz.service.SysOssService;
import io.platform.oss.dto.SysOssDto;
import io.platform.oss.service.client.SysOssServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysOssServiceClientImpl extends BaseServiceClient<SysOss, SysOssDto> implements SysOssServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysOssService sysOssService;

    @Override
    public SysOssDto queryObject(Long id) {
        SysOss sysOss = sysOssService.getById(id);
        SysOssDto sysOssDto = new SysOssDto();
        BeanUtils.copyProperties(sysOss, sysOssDto);
        return sysOssDto;
    }

    @Override
    public List<SysOssDto> queryList(Map<String, Object> map) {
        List<SysOss> sysOssList = sysOssService.selectByMap(map);
        return convertList(sysOssList, SysOssDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysOss> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysOssService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysOssDto sysOssDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysOss sysOss = new SysOss();
            revert(sysOssDto, sysOss);
            boolean flag = sysOssService.save(sysOss);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysOssDto sysOssDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysOss sysOss = new SysOss();
            revert(sysOssDto, sysOss);
            boolean flag = sysOssService.updateById(sysOss);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysOssService.removeById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysOssService.removeByIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysOssDto> getPage(Page<SysOssDto> pageDto, SysOssDto sysOssDto) {
        Page<SysOss> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
//        page.setAsc(pageDto.isAsc());
//        page.setOrderByField(pageDto.getOrderByField());
//        page.setCondition(pageDto.getCondition());
        SysOss sysOss = new SysOss();
        revert(sysOssDto, sysOss);
        QueryWrapper<SysOss> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysOss);
        List<SysOssDto> sysOssDtoList = convertList(sysOssService.page(page, wrapper).getRecords(), SysOssDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(sysOssDtoList);
        return pageDto;
    }
}
