
package io.platform.sms.service.client.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.sms.SailunSmsUtil;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sms.SysSmsLogServiceClient;
import io.platform.sms.biz.entity.SysSmsLog;
import io.platform.sms.biz.service.SysSmsLogService;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysSmsLogDto;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysSmsLogServiceClientImpl extends BaseServiceClient<SysSmsLog,SysSmsLogDto> implements SysSmsLogServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysSmsLogService sysSmsLogService;
    @Resource
    private SysUserService sysUserService;

    @Override
    public SysSmsLogDto queryObject(Long id) {
        SysSmsLog sysSmsLog = sysSmsLogService.getById(id);
        SysSmsLogDto sysSmsLogDto = new SysSmsLogDto();
        BeanUtils.copyProperties(sysSmsLog,sysSmsLogDto);
        return sysSmsLogDto;
    }

    @Override
    public List<SysSmsLogDto> queryList(Map<String, Object> map) {
        List<SysSmsLog> sysSmsLogList = sysSmsLogService.selectByMap(map);
        return convertList(sysSmsLogList, SysSmsLogDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysSmsLog> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysSmsLogService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysSmsLogDto sysSmsLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            //TODO 发送短信

            SysSmsLog sysSmsLog = new SysSmsLog();
            revert(sysSmsLogDto,sysSmsLog);
            boolean flag = sysSmsLogService.save(sysSmsLog);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysSmsLogDto sysSmsLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysSmsLog sysSmsLog = new SysSmsLog();
            revert(sysSmsLogDto,sysSmsLog);

            boolean flag = sysSmsLogService.updateById(sysSmsLog);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysSmsLogService.removeById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysSmsLogService.removeByIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysSmsLogDto> getPage(Page<SysSmsLogDto> pageDto, SysSmsLogDto sysSmsLogDto) {
        Page<SysSmsLog> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());
//        page.setAsc(pageDto.isAsc());
//        page.setOrderByField(pageDto.getOrderByField());
//        page.setCondition(pageDto.getCondition());
        SysSmsLog sysSmsLog = new SysSmsLog();
        revert(sysSmsLogDto,sysSmsLog);
        QueryWrapper<SysSmsLog> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysSmsLog);
        List<SysSmsLogDto> sysSmsLogDtoList = convertList(sysSmsLogService.page(page,wrapper).getRecords(), SysSmsLogDto.class);
//        if (!CollectionUtils.isEmpty(sysSmsLogDtoList)){
//            sysSmsLogDtoList.forEach(s->{
                  //暂时不需要发送人
//                SysUser sysUser = sysUserService.selectById(s.getUserId());
//            });
//        }
        pageDto.setTotal(sysSmsLogService.count(wrapper));
        pageDto.setRecords(sysSmsLogDtoList);
        return pageDto;
    }


    @Override
    public ExecuteResult<String> sendSms(SysSmsLogDto sysSmsLogDto) {
        ExecuteResult result = new ExecuteResult();

//        JSONObject smsResult = JuheSmsUtils.mobileQuery(sysSmsLogDto.getContent(),sysSmsLogDto.getMobile());
        String smsResult = "";
        if ("2".equals(sysSmsLogDto.getValidType())){
            smsResult = SailunSmsUtil.smsRegistCode(sysSmsLogDto.getMobile(),Integer.parseInt(sysSmsLogDto.getContent()));
        }else{
            smsResult = SailunSmsUtil.smsLoginCode(sysSmsLogDto.getMobile(),Integer.parseInt(sysSmsLogDto.getContent()));
        }
        if ("1".equals(sysSmsLogDto.getValidType())){
            sysSmsLogDto.getMobile();

        }
//        String smsResult = SailunSmsUtil.smsLoginCode(sysSmsLogDto.getMobile(),sysSmsLogDto.getContent());
        SysSmsLog sysSmsLog = new SysSmsLog();
        sysSmsLog.setMobile(sysSmsLogDto.getMobile());
        sysSmsLog.setContent(sysSmsLogDto.getContent());
        sysSmsLog.setSendTime(System.currentTimeMillis()/1000);

        sysSmsLog.setReturnMsg(smsResult);
        sysSmsLog.setStime(new Date());

        if(smsResult.indexOf("true")>0){
            result.setSuccessMessage("发送短信成功");
            sysSmsLog.setSendStatus(1);
        }else{
            result.addErrorMessage("短信发送失败");
            sysSmsLog.setSendStatus(0);
        }
        sysSmsLogService.save(sysSmsLog);

        return result;
    }

    @Override
    public Boolean checkValidCode(SysSmsLogDto sysSmsLogDto) {
        QueryWrapper wrapper = new QueryWrapper<SysSmsLog>();//.eq("MOBILE",sysSmsLogDto.getMobile()).eq("CONTENTS",sysSmsLogDto.getContent()).orderBy(false,false,"send_time")
        SysSmsLog sysSmsLog = new SysSmsLog();
        sysSmsLog.setMobile(sysSmsLogDto.getMobile());
        sysSmsLog.setContent(sysSmsLogDto.getContent());
        wrapper.setEntity(sysSmsLog);
        List<SysSmsLog> logList = sysSmsLogService.list(wrapper);
        if (CollectionUtil.isNotEmpty(logList)){
            SysSmsLog lastLog = logList.get(0);
            // 对接短信平台后开通
            if(System.currentTimeMillis()/1000- lastLog.getSendTime()<10*60){
                return true;
            }else{
                return false;
            }
        }
        return false;

    }
}
