
package io.platform.sys.biz.service;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.platform.base.common.exception.RRException;
import io.platform.redis.SysConfigRedis;
import io.platform.sys.biz.entity.SysConfig;
import io.platform.sys.biz.mapper.SysConfigMapper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;


@Service("sysConfigService")
public class SysConfigService extends ServiceImpl<SysConfigMapper, SysConfig> {

    @Autowired
    private SysConfigRedis sysConfigRedis;

    @Transactional(rollbackFor = Exception.class)
    public void updateValueByKey(String key, String value) {
        String origin = getValue(key);
        if (StringUtils.isBlank(origin)){
            SysConfig sysConfig = new SysConfig();
            sysConfig.setParamKey(key);
            sysConfig.setParamLabel("OSS配置");
            sysConfig.setParamValue(value);
            save(sysConfig);
            sysConfigRedis.saveOrUpdate(sysConfig);
        }else{
            baseMapper.updateValueByKey(key, value);
            sysConfigRedis.delete(key);
        }

    }

    public String getValue(String key) {
        SysConfig config = sysConfigRedis.get(key);
        if(config == null){
            config = baseMapper.queryByKey(key);
            sysConfigRedis.saveOrUpdate(config);
        }

        return config == null ? null : config.getParamValue();
    }

    public <T> T getConfigObject(String key, Class<T> clazz) {
        String value = getValue(key);
        if(StringUtils.isNotBlank(value)){
            return JSONObject.parseObject(value, clazz);
        }

        try {
            return clazz.newInstance();
        } catch (Exception e) {
            throw new RRException("获取参数失败");
        }
    }

    public SysConfig getByKey(String key) {
       return baseMapper.queryByKey(key);
    }

    public List<SysConfig> selectByMap(Map<String, Object> map) {
        return baseMapper.selectByMap(map);
    }
}
