
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.redis.SysConfigRedis;
import io.platform.sys.biz.entity.SysConfig;
import io.platform.sys.biz.service.SysConfigService;
import io.platform.sys.dto.SysConfigDto;
import io.platform.sys.service.client.api.SysConfigServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysConfigServiceClientImpl extends BaseServiceClient<SysConfig, SysConfigDto> implements SysConfigServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysConfigService sysConfigService;

    @Autowired
    private SysConfigRedis sysConfigRedis;

    @Override
    public SysConfigDto queryObject(Long id) {
        SysConfig sysConfig = sysConfigService.getById(id);
        SysConfigDto sysConfigDto = new SysConfigDto();
        BeanUtils.copyProperties(sysConfig, sysConfigDto);
        return sysConfigDto;
    }

    @Override
    public List<SysConfigDto> queryList(Map<String, Object> map) {
        List<SysConfig> sysConfigList = sysConfigService.selectByMap(map);
        return convertList(sysConfigList, SysConfigDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysConfig> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysConfigService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysConfigDto sysConfigDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysConfig sysConfig = new SysConfig();
            revert(sysConfigDto, sysConfig);
            boolean flag = sysConfigService.save(sysConfig);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysConfigDto sysConfigDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysConfig sysConfig = new SysConfig();
            revert(sysConfigDto, sysConfig);
            sysConfigRedis.saveOrUpdate(sysConfig);
            boolean flag = sysConfigService.updateById(sysConfig);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysConfigService.removeById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysConfigService.removeByIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysConfigDto> getPage(Page<SysConfigDto> pageDto, SysConfigDto sysConfigDto) {
        Page<SysConfig> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
//        page.setAsc(pageDto.isAsc());
//        page.setOrderByField(pageDto.getOrderByField());
        QueryWrapper<SysConfig> wrapper = new QueryWrapper<>();
        SysConfig sysConfig = new SysConfig();
        revert(sysConfigDto, sysConfig);
        wrapper.setEntity(sysConfig);
        List<SysConfigDto> sysConfigDtoList = convertList(sysConfigService.page(page, wrapper).getRecords(), SysConfigDto.class);
        pageDto.setTotal(sysConfigService.count(wrapper));
        pageDto.setRecords(sysConfigDtoList);
        return pageDto;
    }

    @Override
    public String queryValue(String key) {
        QueryWrapper<SysConfig> ew = new QueryWrapper<>();
        ew.eq("param_key", key);
        SysConfig sysConfig = sysConfigService.getOne(ew);
        if (sysConfig == null) {
            return "err";
        }
        return sysConfig.getParamValue();
    }

    @Override
    public String getValue(String key) {
        return sysConfigService.getValue(key);
    }

    @Override
    public <T> T getConfigObject(String key, Class<T> clazz) {
        return sysConfigService.getConfigObject(key, clazz);
    }

    @Override
    public void updateValueByKey(String key, String value) {
        sysConfigService.updateValueByKey(key, value);
    }

    @Override
    public SysConfigDto getByKey(String key) {
        SysConfigDto dto = new SysConfigDto();
        convert(sysConfigService.getByKey(key),dto);
        return dto;
    }
}
