
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;

import io.platform.sys.biz.entity.SysFile;
import io.platform.sys.biz.service.SysFileService;
import io.platform.sys.dto.SysFileDto;
import io.platform.sys.service.client.api.SysFileServiceClient;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysFileServiceClientImpl extends BaseServiceClient<SysFile,SysFileDto> implements SysFileServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysFileService sysFileService;

    @Override
    public SysFileDto queryObject(Long id) {
        SysFile sysFile = sysFileService.getById(id);
        SysFileDto sysFileDto = new SysFileDto();
        BeanUtils.copyProperties(sysFile,sysFileDto);
        return sysFileDto;
    }

    @Override
    public List<SysFileDto> queryList(Map<String, Object> map) {
        List<SysFile> sysFileList = sysFileService.selectByMap(map);
        return convertList(sysFileList,SysFileDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysFile> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysFileService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysFileDto sysFileDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysFile sysFile = new SysFile();
            revert(sysFileDto,sysFile);
            boolean flag = sysFileService.save(sysFile);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysFileDto sysFileDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysFile sysFile = new SysFile();
            revert(sysFileDto,sysFile);

            boolean flag = sysFileService.updateById(sysFile);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysFileService.removeById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysFileService.removeByIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysFileDto> getPage(Page<SysFileDto> pageDto,SysFileDto sysFileDto) {
        Page<SysFile> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());

        page.setAsc(pageDto.ascs());
        page.setDesc(pageDto.descs());
        if (page.condition()!=null){
            page.condition().putAll(pageDto.condition());
        }

        SysFile sysFile = new SysFile();
        revert(sysFileDto,sysFile);

        QueryWrapper<SysFile> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysFile);

        List<SysFileDto> sysFileDtoList = convertList(sysFileService.page(page,wrapper).getRecords(),SysFileDto.class);
        pageDto.setTotal(sysFileService.count(wrapper));
        pageDto.setRecords(sysFileDtoList);
        return pageDto;
    }


    @Override
    public Page<SysFileDto> pageForAPK(Page<SysFileDto> pageDto, SysFileDto sysFileDto) {
        Page<SysFile> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());

        page.setAsc(pageDto.ascs());
        page.setDesc(pageDto.descs());
        if (page.condition()!=null){
            page.condition().putAll(pageDto.condition());
        }

        SysFile sysFile = new SysFile();
        revert(sysFileDto,sysFile);

        QueryWrapper<SysFile> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysFile);
        wrapper.eq("FILE_TYPE","apk");
        List<SysFileDto> sysFileDtoList = convertList(sysFileService.page(page,wrapper).getRecords(),SysFileDto.class);
        pageDto.setTotal(sysFileService.count(wrapper));
        pageDto.setRecords(sysFileDtoList);
        return pageDto;
    }

}
