
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysLog;
import io.platform.sys.biz.service.SysLogService;
import io.platform.sys.dto.SysLogDto;
import io.platform.sys.service.client.api.SysLogServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysLogServiceClientImpl extends BaseServiceClient<SysLog, SysLogDto> implements SysLogServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysLogService sysLogService;

    @Override
    public SysLogDto queryObject(Long id) {
        SysLog sysLog = sysLogService.getById(id);
        SysLogDto sysLogDto = new SysLogDto();
        BeanUtils.copyProperties(sysLog, sysLogDto);
        return sysLogDto;
    }

    @Override
    public List<SysLogDto> queryList(Map<String, Object> map) {
        List<SysLog> sysLogList = sysLogService.selectByMap(map);
        return convertList(sysLogList, SysLogDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysLog> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysLogService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysLogDto sysLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysLog sysLog = new SysLog();
            revert(sysLogDto, sysLog);
            boolean flag = sysLogService.save(sysLog);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysLogDto sysLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysLog sysLog = new SysLog();
            revert(sysLogDto, sysLog);
            boolean flag = sysLogService.updateById(sysLog);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysLogService.removeById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysLogService.removeByIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysLogDto> getPage(Page<SysLogDto> pageDto, SysLogDto sysLogDto) {
        Page<SysLog> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
//        page.setAsc(pageDto.isAsc());
//        page.setOrderByField(pageDto.getOrderByField());
//        page.setCondition(pageDto.getCondition());
        SysLog sysLog = new SysLog();
        revert(sysLogDto,sysLog);
        QueryWrapper<SysLog> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysLog);

        List<SysLogDto> sysLogDtoList = convertList(sysLogService.page(page, wrapper).getRecords(), SysLogDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(sysLogDtoList);
        return pageDto;
    }
}
