
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysMenu;
import io.platform.sys.biz.service.SysMenuService;
import io.platform.sys.dto.SysMenuDto;
import io.platform.sys.service.client.api.SysMenuServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysMenuServiceClientImpl extends BaseServiceClient<SysMenu, SysMenuDto> implements SysMenuServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysMenuService sysMenuService;

    @Override
    public SysMenuDto queryObject(Long id) {
        SysMenu sysMenu = sysMenuService.getById(id);
        if (sysMenu!=null){
            SysMenuDto sysMenuDto = new SysMenuDto();
            BeanUtils.copyProperties(sysMenu, sysMenuDto);
            return sysMenuDto;
        }else{
            return null;
        }

    }

    @Override
    public List<SysMenuDto> queryList(Map<String, Object> map) {
        List<SysMenu> sysMenuList = sysMenuService.selectByMap(map);
        return convertList(sysMenuList, SysMenuDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysMenu> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysMenuService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysMenuDto sysMenuDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysMenu sysMenu = new SysMenu();
            revert(sysMenuDto, sysMenu);
            boolean flag = sysMenuService.save(sysMenu);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysMenuDto sysMenuDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysMenu sysMenu = new SysMenu();
            revert(sysMenuDto, sysMenu);

            boolean flag = sysMenuService.updateById(sysMenu);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysMenuService.removeById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysMenuService.removeByIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysMenuDto> getPage(Page<SysMenuDto> pageDto, SysMenuDto sysMenuDto) {
        Page<SysMenu> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
//        page.setAsc(pageDto.isAsc());
//        page.setOrderByField(pageDto.getOrderByField());
//        page.setCondition(pageDto.getCondition());
        SysMenu sysMenu = new SysMenu();
        revert(sysMenuDto,sysMenu);
        QueryWrapper<SysMenu> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysMenu);

        List<SysMenuDto> sysMenuDtoList = convertList(sysMenuService.page(page, wrapper).getRecords(), SysMenuDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(sysMenuDtoList);
        return pageDto;
    }

    @Override
    public List<SysMenuDto> getUserMenuList(Long userId) {

        return convertList(sysMenuService.getUserMenuList(userId), SysMenuDto.class);
    }

    @Override
    public List<SysMenuDto> queryNotButtonList() {
        return convertList(sysMenuService.queryNotButtonList(), SysMenuDto.class);
    }

    @Override
    public List<SysMenuDto> queryAllList() {
        List<SysMenu> sysMenuList = sysMenuService.list(new QueryWrapper<>());
        return convertList(sysMenuList, SysMenuDto.class);
    }


    @Override
    public List<SysMenuDto> queryListParentId(long parentId) {
        return convertList(sysMenuService.queryListParentId(parentId), SysMenuDto.class);
    }

}
