
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;


import io.platform.sys.biz.entity.SysMessage;
import io.platform.sys.biz.service.SysMessageService;
import io.platform.sys.dto.SysMessageDto;
import io.platform.sys.service.client.api.SysMessageServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;


/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysMessageServiceClientImpl extends BaseServiceClient<SysMessage,SysMessageDto> implements SysMessageServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysMessageService sysMessageService;

    @Override
    public SysMessageDto queryObject(Long id) {
        SysMessage sysMessage = sysMessageService.getById(id);
        SysMessageDto sysMessageDto = new SysMessageDto();
        BeanUtils.copyProperties(sysMessage,sysMessageDto);
        return sysMessageDto;
    }

    @Override
    public List<SysMessageDto> queryList(Map<String, Object> map) {
        List<SysMessage> sysMessageList = sysMessageService.selectByMap(map);
        return convertList(sysMessageList,SysMessageDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysMessage> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysMessageService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysMessageDto sysMessageDto, String username, Long userId) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMessage sysMessage = new SysMessage();
            revert(sysMessageDto,sysMessage);
            // 创建时间、创建人、创建人userName
            sysMessage.setCreateTime(new Date());
            sysMessage.setCreateUser(userId);
            sysMessage.setCreateUserName(username);
            if ("".equals(sysMessage.getMsgTitle())) {
                sysMessage.setMsgTitle(null);
            }
            boolean flag = sysMessageService.save(sysMessage);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysMessageDto sysMessageDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMessage sysMessage = new SysMessage();
            revert(sysMessageDto,sysMessage);

            boolean flag = sysMessageService.updateById(sysMessage);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMessageService.removeById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMessageService.removeByIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysMessageDto> getPage(Page<SysMessageDto> pageDto,SysMessageDto sysMessageDto) {
        Page<SysMessage> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());
        page.setAsc(pageDto.ascs());
        page.setDesc(pageDto.descs());
        // page.condition().putAll(pageDto.condition());

        SysMessage sysMessage = new SysMessage();
        revert(sysMessageDto,sysMessage);
        if ("".equals(sysMessage.getContentType())) {
            sysMessage.setContentType(null);
        }
        if ("".equals(sysMessage.getMsgTitle())) {
            sysMessage.setMsgTitle(null);
        }
        QueryWrapper<SysMessage> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysMessage);
        List<SysMessageDto> sysMessageDtoList = convertList(sysMessageService.page(page,wrapper).getRecords(),SysMessageDto.class);
        pageDto.setTotal(sysMessageService.count(wrapper));
        pageDto.setRecords(sysMessageDtoList);
        return pageDto;
    }
}
