
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;


import io.platform.sys.biz.entity.SysMetaArea;
import io.platform.sys.biz.service.SysMetaAreaService;
import io.platform.sys.dto.SysMetaAreaDto;
import io.platform.sys.service.client.api.SysMetaAreaServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysMetaAreaServiceClientImpl extends BaseServiceClient<SysMetaArea,SysMetaAreaDto> implements SysMetaAreaServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysMetaAreaService sysMetaAreaService;

    @Override
    public SysMetaAreaDto queryObject(Long id) {
        SysMetaArea sysMetaArea = sysMetaAreaService.getById(id);
        SysMetaAreaDto sysMetaAreaDto = new SysMetaAreaDto();
        BeanUtils.copyProperties(sysMetaArea,sysMetaAreaDto);
        return sysMetaAreaDto;
    }

    @Override
    public List<SysMetaAreaDto> queryList(Map<String, Object> map) {
        List<SysMetaArea> sysMetaAreaList = sysMetaAreaService.selectByMap(map);
        return convertList(sysMetaAreaList,SysMetaAreaDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysMetaArea> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysMetaAreaService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysMetaAreaDto sysMetaAreaDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMetaArea sysMetaArea = new SysMetaArea();
            revert(sysMetaAreaDto,sysMetaArea);
            boolean flag = sysMetaAreaService.save(sysMetaArea);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysMetaAreaDto sysMetaAreaDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMetaArea sysMetaArea = new SysMetaArea();
            revert(sysMetaAreaDto,sysMetaArea);

            boolean flag = sysMetaAreaService.updateById(sysMetaArea);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMetaAreaService.removeById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMetaAreaService.removeByIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysMetaAreaDto> getPage(Page<SysMetaAreaDto> pageDto,SysMetaAreaDto sysMetaAreaDto) {
        Page<SysMetaArea> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());

        page.setAsc(pageDto.ascs());
        page.setDesc(pageDto.descs());
        page.condition().putAll(pageDto.condition());

        SysMetaArea sysMetaArea = new SysMetaArea();
        revert(sysMetaAreaDto,sysMetaArea);

        QueryWrapper<SysMetaArea> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysMetaArea);

        List<SysMetaAreaDto> sysMetaAreaDtoList = convertList(sysMetaAreaService.page(page,wrapper).getRecords(),SysMetaAreaDto.class);
        pageDto.setTotal(sysMetaAreaService.count(wrapper));
        pageDto.setRecords(sysMetaAreaDtoList);
        return pageDto;
    }
}
