
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;

import io.platform.sys.biz.entity.SysMetaCity;
import io.platform.sys.biz.service.SysMetaCityService;
import io.platform.sys.dto.SysMetaCityDto;
import io.platform.sys.service.client.api.SysMetaCityServiceClient;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysMetaCityServiceClientImpl extends BaseServiceClient<SysMetaCity,SysMetaCityDto> implements SysMetaCityServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysMetaCityService sysMetaCityService;

    @Override
    public SysMetaCityDto queryObject(Long id) {
        SysMetaCity sysMetaCity = sysMetaCityService.getById(id);
        SysMetaCityDto sysMetaCityDto = new SysMetaCityDto();
        BeanUtils.copyProperties(sysMetaCity,sysMetaCityDto);
        return sysMetaCityDto;
    }

    @Override
    public List<SysMetaCityDto> queryList(Map<String, Object> map) {
        List<SysMetaCity> sysMetaCityList = sysMetaCityService.selectByMap(map);
        return convertList(sysMetaCityList,SysMetaCityDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysMetaCity> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysMetaCityService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysMetaCityDto sysMetaCityDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMetaCity sysMetaCity = new SysMetaCity();
            revert(sysMetaCityDto,sysMetaCity);
            boolean flag = sysMetaCityService.save(sysMetaCity);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysMetaCityDto sysMetaCityDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMetaCity sysMetaCity = new SysMetaCity();
            revert(sysMetaCityDto,sysMetaCity);

            boolean flag = sysMetaCityService.updateById(sysMetaCity);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMetaCityService.removeById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMetaCityService.removeByIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysMetaCityDto> getPage(Page<SysMetaCityDto> pageDto,SysMetaCityDto sysMetaCityDto) {
        Page<SysMetaCity> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());

        page.setAsc(pageDto.ascs());
        page.setDesc(pageDto.descs());
        page.condition().putAll(pageDto.condition());

        SysMetaCity sysMetaCity = new SysMetaCity();
        revert(sysMetaCityDto,sysMetaCity);

        QueryWrapper<SysMetaCity> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysMetaCity);

        List<SysMetaCityDto> sysMetaCityDtoList = convertList(sysMetaCityService.page(page,wrapper).getRecords(),SysMetaCityDto.class);
        pageDto.setTotal(sysMetaCityService.count(wrapper));
        pageDto.setRecords(sysMetaCityDtoList);
        return pageDto;
    }
}
