
package io.platform.sys.service.client.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;

import io.platform.sys.biz.entity.SysMetaCity;
import io.platform.sys.biz.entity.SysMetaProvince;
import io.platform.sys.biz.service.SysMetaCityService;
import io.platform.sys.biz.service.SysMetaProvinceService;
import io.platform.sys.dto.SysMetaProvinceDto;
import io.platform.sys.service.client.api.SysMetaProvinceServiceClient;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysMetaProvinceServiceClientImpl extends BaseServiceClient<SysMetaProvince,SysMetaProvinceDto> implements SysMetaProvinceServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysMetaProvinceService sysMetaProvinceService;
    @Resource
    private SysMetaCityService sysMetaCityService;

    @Override
    public SysMetaProvinceDto queryObject(Long id) {
        SysMetaProvince sysMetaProvince = sysMetaProvinceService.getById(id);
        SysMetaProvinceDto sysMetaProvinceDto = new SysMetaProvinceDto();
        BeanUtils.copyProperties(sysMetaProvince,sysMetaProvinceDto);
        return sysMetaProvinceDto;
    }

    @Override
    public List<SysMetaProvinceDto> queryList(Map<String, Object> map) {
        List<SysMetaProvince> sysMetaProvinceList = sysMetaProvinceService.selectByMap(map);
        return convertList(sysMetaProvinceList,SysMetaProvinceDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysMetaProvince> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysMetaProvinceService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysMetaProvinceDto sysMetaProvinceDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMetaProvince sysMetaProvince = new SysMetaProvince();
            revert(sysMetaProvinceDto,sysMetaProvince);
            boolean flag = sysMetaProvinceService.save(sysMetaProvince);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysMetaProvinceDto sysMetaProvinceDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMetaProvince sysMetaProvince = new SysMetaProvince();
            revert(sysMetaProvinceDto,sysMetaProvince);

            boolean flag = sysMetaProvinceService.updateById(sysMetaProvince);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMetaProvinceService.removeById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMetaProvinceService.removeByIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysMetaProvinceDto> getPage(Page<SysMetaProvinceDto> pageDto,SysMetaProvinceDto sysMetaProvinceDto) {
        Page<SysMetaProvince> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());

        page.setAsc(pageDto.ascs());
        page.setDesc(pageDto.descs());
        page.condition().putAll(pageDto.condition());

        SysMetaProvince sysMetaProvince = new SysMetaProvince();
        revert(sysMetaProvinceDto,sysMetaProvince);

        QueryWrapper<SysMetaProvince> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysMetaProvince);

        List<SysMetaProvinceDto> sysMetaProvinceDtoList = convertList(sysMetaProvinceService.page(page,wrapper).getRecords(),SysMetaProvinceDto.class);
        pageDto.setTotal(sysMetaProvinceService.count(wrapper));
        pageDto.setRecords(sysMetaProvinceDtoList);
        return pageDto;
    }

    // 获取省市数据
    @Override
    public Object getProvinceAndCity() {
        List<SysMetaProvince> metaProvinces = sysMetaProvinceService.selectByMap(null);
        Map<String,Object> map = new HashMap<>();
        for (int i = 0; i < metaProvinces.size(); i++) {
            // 根据省份查市
            SysMetaCity sysMetaCity = new SysMetaCity();
            map.put("PARENT_CODE",metaProvinces.get(i).getCode());
            List<SysMetaCity> sysMetaCities = sysMetaCityService.selectByMap(map);
            metaProvinces.get(i).setCitys(sysMetaCities);
        }
        return metaProvinces;
    }
}
