
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;


import io.platform.sys.biz.entity.SysMetaStreet;
import io.platform.sys.biz.service.SysMetaStreetService;
import io.platform.sys.dto.SysMetaStreetDto;
import io.platform.sys.service.client.api.SysMetaStreetServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysMetaStreetServiceClientImpl extends BaseServiceClient<SysMetaStreet,SysMetaStreetDto> implements SysMetaStreetServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysMetaStreetService sysMetaStreetService;

    @Override
    public SysMetaStreetDto queryObject(Long id) {
        SysMetaStreet sysMetaStreet = sysMetaStreetService.getById(id);
        SysMetaStreetDto sysMetaStreetDto = new SysMetaStreetDto();
        BeanUtils.copyProperties(sysMetaStreet,sysMetaStreetDto);
        return sysMetaStreetDto;
    }

    @Override
    public List<SysMetaStreetDto> queryList(Map<String, Object> map) {
        List<SysMetaStreet> sysMetaStreetList = sysMetaStreetService.selectByMap(map);
        return convertList(sysMetaStreetList,SysMetaStreetDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysMetaStreet> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysMetaStreetService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysMetaStreetDto sysMetaStreetDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMetaStreet sysMetaStreet = new SysMetaStreet();
            revert(sysMetaStreetDto,sysMetaStreet);
            boolean flag = sysMetaStreetService.save(sysMetaStreet);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysMetaStreetDto sysMetaStreetDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysMetaStreet sysMetaStreet = new SysMetaStreet();
            revert(sysMetaStreetDto,sysMetaStreet);

            boolean flag = sysMetaStreetService.updateById(sysMetaStreet);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMetaStreetService.removeById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysMetaStreetService.removeByIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysMetaStreetDto> getPage(Page<SysMetaStreetDto> pageDto,SysMetaStreetDto sysMetaStreetDto) {
        Page<SysMetaStreet> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());

        page.setAsc(pageDto.ascs());
        page.setDesc(pageDto.descs());
        page.condition().putAll(pageDto.condition());

        SysMetaStreet sysMetaStreet = new SysMetaStreet();
        revert(sysMetaStreetDto,sysMetaStreet);

        QueryWrapper<SysMetaStreet> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysMetaStreet);

        List<SysMetaStreetDto> sysMetaStreetDtoList = convertList(sysMetaStreetService.page(page,wrapper).getRecords(),SysMetaStreetDto.class);
        pageDto.setTotal(sysMetaStreetService.count(wrapper));
        pageDto.setRecords(sysMetaStreetDtoList);
        return pageDto;
    }
}
