
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysOpreaLog;
import io.platform.sys.biz.service.SysOpreaLogService;
import io.platform.sys.dto.SysOpreaLogDto;
import io.platform.sys.service.client.api.SysOpreaLogServiceClient;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;
import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysOpreaLogServiceClientImpl extends BaseServiceClient<SysOpreaLog,SysOpreaLogDto> implements SysOpreaLogServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysOpreaLogService sysOpreaLogService;

    @Override
    public SysOpreaLogDto queryObject(Long id) {
        SysOpreaLog sysOpreaLog = sysOpreaLogService.getById(id);
        SysOpreaLogDto sysOpreaLogDto = new SysOpreaLogDto();
        BeanUtils.copyProperties(sysOpreaLog,sysOpreaLogDto);
        return sysOpreaLogDto;
    }

    @Override
    public List<SysOpreaLogDto> queryList(Map<String, Object> map) {
        List<SysOpreaLog> sysOpreaLogList = sysOpreaLogService.selectByMap(map);
        return convertList(sysOpreaLogList,SysOpreaLogDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysOpreaLog> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysOpreaLogService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysOpreaLogDto sysOpreaLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysOpreaLog sysOpreaLog = new SysOpreaLog();
            revert(sysOpreaLogDto,sysOpreaLog);
            boolean flag = sysOpreaLogService.save(sysOpreaLog);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysOpreaLogDto sysOpreaLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysOpreaLog sysOpreaLog = new SysOpreaLog();
            revert(sysOpreaLogDto,sysOpreaLog);

            boolean flag = sysOpreaLogService.updateById(sysOpreaLog);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysOpreaLogService.removeById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysOpreaLogService.removeByIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysOpreaLogDto> getPage(Page<SysOpreaLogDto> pageDto,SysOpreaLogDto sysOpreaLogDto) {
        Page<SysOpreaLog> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());

        page.setAsc(pageDto.ascs());
        page.setDesc(pageDto.descs());
        page.condition().putAll(pageDto.condition());

        SysOpreaLog sysOpreaLog = new SysOpreaLog();
        revert(sysOpreaLogDto,sysOpreaLog);

        QueryWrapper<SysOpreaLog> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysOpreaLog);

        List<SysOpreaLogDto> sysOpreaLogDtoList = convertList(sysOpreaLogService.page(page,wrapper).getRecords(),SysOpreaLogDto.class);
        pageDto.setTotal(sysOpreaLogService.count(wrapper));
        pageDto.setRecords(sysOpreaLogDtoList);
        return pageDto;
    }
}
