
package io.platform.sys.service.client.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysRole;
import io.platform.sys.biz.service.SysRoleMenuService;
import io.platform.sys.biz.service.SysRoleService;
import io.platform.sys.dto.SysRoleDto;
import io.platform.sys.service.client.api.SysRoleServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysRoleServiceClientImpl extends BaseServiceClient<SysRole, SysRoleDto> implements SysRoleServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysRoleService sysRoleService;
    @Resource
    private SysRoleMenuService sysRoleMenuService;

    @Override
    public SysRoleDto queryObject(Long roleId) {
        SysRole sysRole = sysRoleService.getById(roleId);

        SysRoleDto sysRoleDto = new SysRoleDto();
        BeanUtils.copyProperties(sysRole, sysRoleDto);
        //查询角色对应的菜单
        List<Long> menuIdList = sysRoleMenuService.queryMenuIdList(roleId);
        sysRoleDto.setMenuIdList(menuIdList);
        return sysRoleDto;
    }

    @Override
    public List<SysRoleDto> queryList(Map<String, Object> map) {
        List<SysRole> sysRoleList = sysRoleService.selectByMap(map);
        return convertList(sysRoleList, SysRoleDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysRole> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysRoleService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysRoleDto sysRoleDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysRole sysRole = new SysRole();
            revert(sysRoleDto, sysRole);
            sysRole.setMenuIdList(sysRoleDto.getMenuIdList());
            sysRoleService.save(sysRole);
            result.setSuccessMessage("创建成功");
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysRoleDto sysRoleDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysRole sysRole = sysRoleService.getById(sysRoleDto.getRoleId());
            if (CollectionUtil.isNotEmpty(sysRoleDto.getMenuIdList())){
                sysRole.setMenuIdList(sysRoleDto.getMenuIdList());
            }
            if (!StringUtils.isEmpty(sysRoleDto.getRoleName())){
                sysRole.setRoleName(sysRoleDto.getRoleName());
            }
            if (!StringUtils.isEmpty(sysRoleDto.getRemark())){
                sysRole.setRemark(sysRoleDto.getRemark());
            }
            sysRoleService.update(sysRole);
            result.setSuccessMessage("更新成功");
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysRoleService.removeById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysRoleService.removeByIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysRoleDto> getPage(Page<SysRoleDto> pageDto, SysRoleDto sysRoleDto) {
        Page<SysRole> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
//        page.setAsc(pageDto.isAsc());
//        page.setOrderByField(pageDto.getOrderByField());
//        page.setCondition(pageDto.getCondition());
        SysRole sysRole = new SysRole();
        revert(sysRoleDto, sysRole);
        QueryWrapper<SysRole> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysRole);

        List<SysRoleDto> sysRoleMenuDtoList = convertList(sysRoleService.page(page, wrapper).getRecords(), SysRoleDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(sysRoleMenuDtoList);
        return pageDto;
    }
}
