
package io.platform.sys.service.client.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysUserDto;
import io.platform.sys.service.client.api.SysUserServiceClient;
import org.apache.commons.lang.StringUtils;
import org.apache.shiro.crypto.hash.Sha256Hash;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysUserServiceClientImpl extends BaseServiceClient<SysUser, SysUserDto> implements SysUserServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysUserService sysUserService;

    @Override
    public SysUserDto queryObject(Long id) {
        SysUser sysUser = sysUserService.getById(id);
        SysUserDto sysUserDto = new SysUserDto();
        BeanUtils.copyProperties(sysUser, sysUserDto);
        return sysUserDto;
    }

    @Override
    public List<SysUserDto> queryList(Map<String, Object> map) {
        List<SysUser> sysUserList = sysUserService.selectByMap(map);
        return convertList(sysUserList, SysUserDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysUser> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysUserService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysUser sysUser = new SysUser();
            revert(sysUserDto, sysUser);
            if (CollectionUtil.isNotEmpty(sysUserDto.getRoleIdList())){
                sysUser.setRoleIdList(sysUserDto.getRoleIdList());
            }
            boolean flag = sysUserService.save(sysUser);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if(StringUtils.isNotBlank(sysUserDto.getPassword())){
                sysUserDto.setPassword(new Sha256Hash(sysUserDto.getPassword(), sysUserDto.getSalt()).toHex());
            }
            SysUser sysUser = sysUserService.getById(sysUserDto.getUserId());
            revert(sysUserDto, sysUser);
            if (CollectionUtil.isNotEmpty(sysUserDto.getRoleIdList())){
                sysUser.setRoleIdList(sysUserDto.getRoleIdList());
            }
            sysUserService.update(sysUser);
            result.setSuccessMessage("更新成功");
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysUserService.removeById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysUserService.removeByIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysUserDto> getPage(Page<SysUserDto> pageDto, SysUserDto sysUserDto) {
        Page<SysUser> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());
//        page.setAsc(pageDto.isAsc());
//        page.setOrderByField(pageDto.getOrderByField());
//        page.setCondition(pageDto.getCondition());
        SysUser sysUser = new SysUser();
        revert(sysUserDto,sysUser);
        QueryWrapper<SysUser> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysUser);

        List<SysUserDto> sysUserDtoList = convertList(sysUserService.page(page,wrapper).getRecords(), SysUserDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(sysUserDtoList);
        return pageDto;
    }

    @Override
    public SysUserDto selectByUserName(String username) {
        SysUser sysUser = sysUserService.queryByUserName(username);

        SysUserDto sysUserDto = new SysUserDto();
        convert(sysUser, sysUserDto);
        return sysUserDto;
    }

    @Override
    public boolean updatePassword(Long userId, String password, String newPassword) {
        return sysUserService.updatePassword(userId, password, newPassword);
    }

    @Override
    public List<String> queryAllPerms(Long userId) {
        return sysUserService.queryAllPerms(userId);
    }

    @Override
    public List<Long> queryAllMenuId(Long userId) {
        return sysUserService.queryAllMenuId(userId);
    }
}
