
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysUserToken;
import io.platform.sys.biz.service.SysUserTokenService;
import io.platform.sys.dto.SysUserTokenDto;
import io.platform.sys.service.client.api.SysUserTokenServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysUserTokenServiceClientImpl extends BaseServiceClient<SysUserToken, SysUserTokenDto> implements SysUserTokenServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysUserTokenService sysUserTokenService;

    @Override
    public SysUserTokenDto queryObject(Long id) {
        SysUserToken sysUserToken = sysUserTokenService.getById(id);
        SysUserTokenDto sysUserTokenDto = new SysUserTokenDto();
        if(sysUserToken!=null) {
            BeanUtils.copyProperties(sysUserToken, sysUserTokenDto);
        }else{
            return null;
        }
        return sysUserTokenDto;
    }

    @Override
    public List<SysUserTokenDto> queryList(Map<String, Object> map) {
        List<SysUserToken> sysUserTokenList = sysUserTokenService.selectByMap(map);
        return convertList(sysUserTokenList, SysUserTokenDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysUserToken> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysUserTokenService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysUserTokenDto sysUserTokenDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysUserToken sysUserToken = new SysUserToken();
            revert(sysUserTokenDto, sysUserToken);
            boolean flag = sysUserTokenService.save(sysUserToken);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysUserTokenDto sysUserTokenDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysUserToken sysUserToken = new SysUserToken();
            revert(sysUserTokenDto, sysUserToken);
            boolean flag = sysUserTokenService.updateById(sysUserToken);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysUserTokenService.removeById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysUserTokenService.removeByIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysUserTokenDto> getPage(Page<SysUserTokenDto> pageDto, SysUserTokenDto sysUserTokenDto) {
        Page<SysUserToken> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
//        page.setAsc(pageDto.isAsc());
//        page.setOrderByField(pageDto.getOrderByField());
//        page.setCondition(pageDto.getCondition());
        SysUserToken sysUserToken = new SysUserToken();
        revert(sysUserTokenDto,sysUserToken);
        QueryWrapper<SysUserToken> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysUserToken);
        List<SysUserTokenDto> sysUserTokenDtoList = convertList(sysUserTokenService.page(page, wrapper).getRecords(), SysUserTokenDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(sysUserTokenDtoList);
        return pageDto;
    }

    @Override
    public SysUserTokenDto selectOne(String token) {
        SysUserToken sysUserToken = new SysUserToken();
        sysUserToken.setToken(token);
        sysUserToken = sysUserTokenService.getOne(new QueryWrapper<>(sysUserToken));
        if (sysUserToken != null) {
            SysUserTokenDto dto = new SysUserTokenDto();
            convert(sysUserToken, dto);
            return dto;
        } else {
            return null;
        }


    }
}
