
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.TbUser;
import io.platform.sys.biz.service.TbUserService;
import io.platform.sys.dto.TbUserDto;
import io.platform.sys.service.client.api.TbUserServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class TbUserServiceClientImpl extends BaseServiceClient<TbUser, TbUserDto> implements TbUserServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private TbUserService tbUserService;

    @Override
    public TbUserDto queryObject(Long id) {
        TbUser tbUser = tbUserService.getById(id);
        TbUserDto tbUserDto = new TbUserDto();
        BeanUtils.copyProperties(tbUser, tbUserDto);
        return tbUserDto;
    }

    @Override
    public List<TbUserDto> queryList(Map<String, Object> map) {
        List<TbUser> tbUserList = tbUserService.selectByMap(map);
        return convertList(tbUserList, TbUserDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<TbUser> ew = new QueryWrapper<>();
        ew.allEq(map);
        return tbUserService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(TbUserDto tbUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            TbUser tbUser = new TbUser();
            revert(tbUserDto, tbUser);
            boolean flag = tbUserService.save(tbUser);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(TbUserDto tbUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            TbUser tbUser = new TbUser();
            revert(tbUserDto, tbUser);
            boolean flag = tbUserService.updateById(tbUser);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = tbUserService.removeById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = tbUserService.removeByIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<TbUserDto> getPage(Page<TbUserDto> pageDto, TbUserDto tbUserDto) {
        Page<TbUser> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
//        page.setAsc(pageDto.isAsc());
//        page.setOrderByField(pageDto.getOrderByField());
//        page.setCondition(pageDto.getCondition());

        TbUser tbUser = new TbUser();
        revert(tbUserDto,tbUser);
        QueryWrapper<TbUser> wrapper = new QueryWrapper<>();
        wrapper.setEntity(tbUser);

        List<TbUserDto> tbUserDtoList = convertList(tbUserService.page(page, wrapper).getRecords(), TbUserDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(tbUserDtoList);
        return pageDto;
    }
}
